
#ifndef LIBPALA_EXPORT_H
#define LIBPALA_EXPORT_H

#ifdef LIBPALA_STATIC_DEFINE
#  define LIBPALA_EXPORT
#  define LIBPALA_NO_EXPORT
#else
#  ifndef LIBPALA_EXPORT
#    ifdef pala_EXPORTS
        /* We are building this library */
#      define LIBPALA_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define LIBPALA_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef LIBPALA_NO_EXPORT
#    define LIBPALA_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef LIBPALA_DEPRECATED
#  define LIBPALA_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LIBPALA_DEPRECATED_EXPORT
#  define LIBPALA_DEPRECATED_EXPORT LIBPALA_EXPORT LIBPALA_DEPRECATED
#endif

#ifndef LIBPALA_DEPRECATED_NO_EXPORT
#  define LIBPALA_DEPRECATED_NO_EXPORT LIBPALA_NO_EXPORT LIBPALA_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBPALA_NO_DEPRECATED
#    define LIBPALA_NO_DEPRECATED
#  endif
#endif

#endif /* LIBPALA_EXPORT_H */
